Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type AuthorizeController ¶
type AuthorizeController struct {
// contains filtered or unexported fields
}
func NewAuthorizeController ¶
func NewAuthorizeController(u *usecase.AuthorizeUsecase) *AuthorizeController
func (*AuthorizeController) GetAuthorize ¶
func (ac *AuthorizeController) GetAuthorize(c *gin.Context)
@Summary get authorize @Description get authorize @Tags authorize @Param response_type query string true "code for Authorization Code Grant" Enums(code) @Param client_id query string true "OAuth 2.0 Client Identifier valid at the Authorization Server." @Param redirect_uri query string true "Redirection URI to which the response will be sent." @Param scope query string true "OpenID Connect requests MUST contain the openid scope value." @Param state query string true "Opaque value used to maintain state between the request and the callback." @Param code_challenge query string true "https://datatracker.ietf.org/doc/html/rfc7636" @Param code_challenge_method query string true "https://datatracker.ietf.org/doc/html/rfc7636" Enums(S256) @Success 200 @Failure 400 {object} domain.HTTPError @Router /authorize [get]
type DecisionController ¶
type DecisionController struct {
// contains filtered or unexported fields
}
func NewDecisionController ¶
func NewDecisionController(u *usecase.DecisionUsecase) *DecisionController
func (*DecisionController) PostDecision ¶
func (ac *DecisionController) PostDecision(c *gin.Context)
@Summary get decision @Description get decision @Tags decision @Accept x-www-form-urlencoded @Param email query string true "email" Format(email) @Param password query string true "password" @Success 302 @Header 302 {string} Location "https://client.example.org/cb?code=SplxlOBeZQQYbYS6WxSbIA&state=af0ifjsldkj" @Failure 400 {object} domain.HTTPError @Router /decision [post]
type HealthController ¶
type HealthController struct{}
func NewHealthController ¶
func NewHealthController() *HealthController
func (*HealthController) GetHealth ¶
func (ac *HealthController) GetHealth(c *gin.Context)
@Summary get health @Description get health @Tags health @Accept json @Produce json @Success 204 {object} domain.HTTPEmpty @Router /v1/health [get]
type TokenController ¶
type TokenController struct {
// contains filtered or unexported fields
}
func NewTokenController ¶
func NewTokenController(u *usecase.TokenUsecase) *TokenController
func (*TokenController) PostToken ¶
func (ac *TokenController) PostToken(c *gin.Context)
@Summary post token @Description post token @Tags token @Accept json @Produce json @Param grant_type query string true "Value MUST be set to authorization_code" Enums(authorization_code) @Param code query string true "The authorization code received from the authorization server" @Param redirect_uri query string true "if the redirect_uri parameter was included in the authorization request as described in Section 4.1.1, and their values MUST be identical." @Param client_id query string true "if the client is not authenticating with the authorization server as described in Section 3.2.1" @Success 200 {object} domain.Token @Failure 400 {object} domain.HTTPError @Router /token [post]